@@ -37,6 +37,7 @@ import warnings
 
 import analytix
 from analytix.errors import InvalidRequest
+from analytix.oidc import Scopes
 from analytix.reports import data
 from analytix.reports import types as rt
 from analytix.warnings import InvalidMonthFormatWarning
@@ -118,7 +119,7 @@ class ReportQuery:
             f"&includeHistoricalData={self.include_historical_data}"
         )
 
-    def validate(self) -> None:
+    def validate(self, scopes: Scopes) -> None:
         _log.info("Validating request")
 
         if self.max_results < 0:
@@ -142,6 +143,7 @@ class ReportQuery:
                 "Correcting start and end dates -- if 'month' is passed as a "
                 "dimension, these should always be the first day of the month",
                 InvalidMonthFormatWarning,
+                stacklevel=4,
             )
             self._start_date = dt.date(self._start_date.year, self._start_date.month, 1)
             self._end_date = dt.date(self._end_date.year, self._end_date.month, 1)
@@ -163,7 +165,13 @@ class ReportQuery:
             self.metrics = [
                 m for m in data.ALL_METRICS_ORDERED if m in self.rtype.metrics.values
             ]
-            _log.debug("Metrics set to: " + ", ".join(self.metrics))
+
+        if Scopes.MONETARY_READONLY.value not in scopes.value:
+            self.metrics = [m for m in self.metrics if m not in data.REVENUE_METRICS]
+        elif Scopes.READONLY.value not in scopes.value:
+            self.metrics = [m for m in self.metrics if m in data.REVENUE_METRICS]
+
+        _log.debug("Metrics set to: " + ", ".join(self.metrics))
 
         diff = {o.strip("-") for o in self.sort_options} - set(self.metrics)
         if diff:
